diff Core.lua @ 61:cf2b6b9a8337 v23

6.2 update, shopping list bug fixes, ui scale option
author yellowfive
date Tue, 23 Jun 2015 00:27:21 -0700
parents ee701ce45354
children 69db1c3025ac
line wrap: on
line diff
--- a/Core.lua	Sun Jun 07 15:20:25 2015 -0700
+++ b/Core.lua	Tue Jun 23 00:27:21 2015 -0700
@@ -87,7 +87,8 @@
 			shopWindow = {},           -- shopping list window position settings
 			options = {
 				autoGear = false,      -- auto-equip saved gear sets when changing specs
-				shopAh = false         -- auto-show shopping list at AH
+				shopAh = false,        -- auto-show shopping list at AH
+				uiScale = 1            -- custom scale for AMR UI
 			},
 			Logging = {                -- global logging settings
 				Auto = {}              -- for each instanceId, for each difficultyId, true if auto-logging enabled
@@ -211,6 +212,7 @@
 	version   = "PrintVersions",
 	wipe      = "Wipe",
 	undowipe  = "UndoWipe",
+	reset     = "Reset",
 	test      = "Test"
 }